@@ -3,7 +3,6 @@
 
 use log::Level;
 
-pub const VERSION: &'static str = "0.4.3";
 pub const TEMP_LOG_LEVEL: Level = Level::Info;
 pub const TEMP_DIR: &'static str = "temprs";
 pub const MASTER_RECORD_FILENAME: &'static str = "temprs-stack";
@@ -16,6 +15,5 @@ pub const ERR_INVALID_RM: &'static str = "Could not remove specified temporary f
 pub const ERR_INVALID_INSERT: &'static str = "Could not insert at specified index";
 pub const ERR_INVALID_IDX: &'static str = "Invalid specified index";
 pub const ERR_INVALID_FILE: &'static str = "Invalid specified file argument";
-pub const DESC: &'static str = "A temporary file manager with stack mechanism";
 pub const NAME: &'static str = "temprs";
 pub const HR_CHAR: &'static str = "-";
